@@ -9,23 +9,21 @@
 #' @examples
 #' \donttest{
 #' #Replication of Chatzianzoniou, Gabauer and Stenfors (2022)
-#' #data(cgs2022)
-#' #dca = ConnectednessApproach(cgs2022, 
-#' #                            nlag=1, 
-#' #                            nfore=10, 
-#' #                            window.size=250,
-#' #                            model="TVP-VAR",
-#' #                            connectedness="Time",
-#' #                            VAR_config=list(TVPVAR=list(kappa1=0.99, kappa2=0.99, 
-#' #                            prior="BayesPrior")))
-#' #cc = ConditionalConnectedness(dca, group=c(1,4,7,10,13,16))
+#' data("cgs2022")
+#' dca = ConnectednessApproach(cgs2022, 
+#'                             nlag=1, 
+#'                             nfore=10, 
+#'                             window.size=250,
+#'                             model="VAR",
+#'                             connectedness="Time")
+#' cc = ConditionalConnectedness(dca, group=c(1,4,7,10,13,16))
 #' }
 #' @references Chatziantoniou, I., Gabauer, D., & Stenfors, A. (2021). Independent Policy, Dependent Outcomes: A Game of Cross-Country Dominoes across European Yield Curves (No. 2021-06). University of Portsmouth, Portsmouth Business School, Economics and Finance Subject Group.
 #' @author David Gabauer
 #' @export
 ConditionalConnectedness = function(dca, group=c(1,2,3), start=NULL, end=NULL) {
   corrected = dca$config$corrected
-  message("Conditional connectedness measures are implemented according to:\n Chatziantoniou, I., Gabauer, D., & Stenfors, A. (2021). Independent Policy, Dependent Outcomes: A Game of Cross-Country Dominoes across European Yield Curves (No. 2021-06). University of Portsmouth, Portsmouth Business School, Economics and Finance Subject Group.")
+  message("Conditional connectedness measures are implemented according to:\n Stenfors, A., Chatziantoniou, I., & Gabauer, D. (2022). Independent Policy, Dependent Outcomes: A Game of Cross-Country Dominoes across European Yield Curves. Journal of International Financial Markets, Institutions and Money.")
   k = length(group)
   if (is.null(start)) {
     start = 1
